@@ -30,11 +30,11 @@ using namespace Kontact;
 #include <KAboutData>
 #include <KActionCollection>
 #include <KActionMenu>
+#include <KColorSchemeManager>
 #include <KConfigGroup>
 #include <KDialogJobUiDelegate>
 #include <KEditToolBar>
 #include <KHelpClient>
-#include <KHelpMenu>
 #include <KIO/CommandLauncherJob>
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
@@ -46,14 +46,17 @@ using namespace Kontact;
 #include <KSqueezedTextLabel>
 #include <KStandardAction>
 #include <KSycoca>
+#include <KToggleAction>
 #include <KToolBar>
 #include <KWindowConfig>
 #include <KXMLGUIFactory>
 #include <QAction>
 #include <QApplication>
 #include <QDBusConnection>
+#include <QFontDatabase>
 #include <QHBoxLayout>
 #include <QIcon>
+#include <QMenuBar>
 #include <QShortcut>
 #include <QSplitter>
 #include <QStackedWidget>
@@ -76,9 +79,13 @@ MainWindow::MainWindow()
 
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/KontactInterface"), this, QDBusConnection::ExportScriptableSlots);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     // Set this to be the group leader for all subdialogs - this means
     // modal subdialogs will only affect this dialog, not the other windows
     setAttribute(Qt::WA_GroupLeader);
+#else
+#pragma "Port it"
+#endif
 
     initGUI();
     initObject();
@@ -91,6 +98,8 @@ MainWindow::MainWindow()
     KConfigGroup grp(KSharedConfig::openConfig(), "MainWindow");
     KWindowConfig::restoreWindowSize(windowHandle(), grp);
     setAutoSaveSettings();
+    mShowMenuBarAction->setChecked(Prefs::self()->showMenuBar());
+    slotToggleMenubar(true);
 }
 
 void MainWindow::initGUI()
@@ -130,9 +139,10 @@ void MainWindow::initObject()
             qFatal("KSycoca unavailable. Kontact will be unable to find plugins.");
         }
     }
-    mPluginMetaData = KPluginMetaData::findPlugins(QStringLiteral("kontact5"), [](const KPluginMetaData &data) {
-        return data.rawData().value(QStringLiteral("X-KDE-KontactPluginVersion")).toInt() == KONTACT_PLUGIN_VERSION;
-    });
+    mPluginMetaData =
+        KPluginMetaData::findPlugins(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kontact"), [](const KPluginMetaData &data) {
+            return data.rawData().value(QStringLiteral("X-KDE-KontactPluginVersion")).toInt() == KONTACT_PLUGIN_VERSION;
+        });
 
     // prepare the part manager
     mPartManager = new KParts::PartManager(this);
@@ -303,6 +313,56 @@ void MainWindow::setupActions()
     actionCollection()->addAction(QStringLiteral("hide_show_sidebar"), mShowHideAction);
     actionCollection()->setDefaultShortcut(mShowHideAction, QKeySequence(Qt::Key_F9));
     connect(mShowHideAction, &QAction::triggered, this, &MainWindow::slotShowHideSideBar);
+
+    mShowFullScreenAction = KStandardAction::fullScreen(nullptr, nullptr, this, actionCollection());
+    actionCollection()->setDefaultShortcut(mShowFullScreenAction, Qt::Key_F11);
+    connect(mShowFullScreenAction, &QAction::toggled, this, &MainWindow::slotFullScreen);
+
+    auto manager = new KColorSchemeManager(this);
+    actionCollection()->addAction(QStringLiteral("colorscheme_menu"), manager->createSchemeSelectionMenu(this));
+
+    mShowMenuBarAction = KStandardAction::showMenubar(this, &MainWindow::slotToggleMenubar, actionCollection());
+}
+
+void MainWindow::slotToggleMenubar(bool dontShowWarning)
+{
+    if (menuBar()) {
+        if (mShowMenuBarAction->isChecked()) {
+            menuBar()->show();
+        } else {
+            if (!dontShowWarning && (!toolBar()->isVisible() /* || !toolBar()->actions().contains(mHamburgerMenu)*/)) {
+                const QString accel = mShowMenuBarAction->shortcut().toString();
+                KMessageBox::information(this,
+                                         i18n("<qt>This will hide the menu bar completely."
+                                              " You can show it again by typing %1.</qt>",
+                                              accel),
+                                         i18n("Hide menu bar"),
+                                         QStringLiteral("HideMenuBarWarning"));
+            }
+            menuBar()->hide();
+        }
+        Prefs::self()->setShowMenuBar(mShowMenuBarAction->isChecked());
+    }
+}
+
+void MainWindow::slotFullScreen(bool t)
+{
+    KToggleFullScreenAction::setFullScreen(this, t);
+    QMenuBar *mb = menuBar();
+    if (t) {
+        auto b = new QToolButton(mb);
+        b->setDefaultAction(mShowFullScreenAction);
+        b->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Ignored));
+        b->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
+        mb->setCornerWidget(b, Qt::TopRightCorner);
+        b->setVisible(true);
+        b->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+    } else {
+        QWidget *w = mb->cornerWidget(Qt::TopRightCorner);
+        if (w) {
+            w->deleteLater();
+        }
+    }
 }
 
 KontactInterface::Plugin *MainWindow::pluginFromName(const QString &identifier) const
@@ -380,7 +440,7 @@ void MainWindow::loadPlugins()
 
     std::sort(mPlugins.begin(), mPlugins.end(), pluginWeightLessThan); // all plugins
 
-    // sort the action plugins again and reset shortcuts. If we removed and then readded some plugins
+    // sort the action plugins again and reset shortcuts. If we removed and then read some plugins
     // we need to take in count their weights for setting shortcuts again
     std::sort(mActionPlugins.begin(), mActionPlugins.end(), pluginActionWeightLessThan);
 
@@ -717,7 +777,7 @@ void MainWindow::slotPreferences()
         });
 
         // Add the main contact KCM which is not associated with a specific plugin
-        dlg->addModule(KPluginMetaData(QStringLiteral("pim/kcms/kontact/kcm_kontact")));
+        dlg->addModule(KPluginMetaData(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kcms/kontact/kcm_kontact")));
 
         auto sortByWeight = [](const KPluginMetaData &m1, const KPluginMetaData &m2) {
             return m1.rawData().value(QStringLiteral("X-KDE-Weight")).toInt() < m2.rawData().value(QStringLiteral("X-KDE-Weight")).toInt();
